==> plugin-highlight-code-1.5.16.tgz: package/CHANGELOG.md <==
## [1.5.7](https://github.com/fiction-com/factor/compare/v1.5.6...v1.5.7) (2020-03-24)


### Bug Fixes

* extend ([5e7abd6](https://github.com/fiction-com/factor/commit/5e7abd694919110e97382dcd4db1eab62f8d4f2a))



## [1.5.4](https://github.com/fiction-com/factor/compare/v1.5.3...v1.5.4) (2020-03-24)


### Bug Fixes

* **plugins:** svg icons ([2090322](https://github.com/fiction-com/factor/commit/2090322a2868420f85a8ff914a0ee7cfa2f99b4a))



## [1.4.2](https://github.com/fiction-com/factor/compare/v1.4.1...v1.4.2) (2020-02-27)


### Bug Fixes

* tweak fiction ([41ebfd6](https://github.com/fiction-com/factor/commit/41ebfd6689a3ac8dfd94a0ea6fd234c1345f043b))



## [1.3.11](https://github.com/fiction-com/factor/compare/v1.3.10...v1.3.11) (2020-02-21)


### Features

* forum ([1dbceed](https://github.com/fiction-com/factor/commit/1dbceed1db80f7f2ddeac2785c95c233c3e54fc3))



## [1.3.8](https://github.com/fiction-com/factor/compare/v1.3.7...v1.3.8) (2020-02-19)


### Features

* **forum:** closer ([506390e](https://github.com/fiction-com/factor/commit/506390e6606a564506180cb763a8052e684c3bc4))



## [1.3.5](https://github.com/fiction-com/factor/compare/v1.3.4...v1.3.5) (2020-02-17)


### Bug Fixes

* old code ([50a50be](https://github.com/fiction-com/factor/commit/50a50bec02a7f231bfd58ee1169f992cf76d6061))
* old css ([ffa1bb5](https://github.com/fiction-com/factor/commit/ffa1bb54079c1f6a3ce5492496b22a81ddccb91a))


### Features

* **code:** highlight ([d52a121](https://github.com/fiction-com/factor/commit/d52a121efd48074bc8b24f00bdf364cea55effff))
* **forum:** refactor ([4aa89bb](https://github.com/fiction-com/factor/commit/4aa89bb75afb09e202717f1509c74266fc08d9aa))



## [1.3.1](https://github.com/fiction-com/factor/compare/v1.3.0...v1.3.1) (2020-02-04)



# [1.3.0](https://github.com/fiction-com/factor/compare/v1.2.10...v1.3.0) (2020-02-04)



## [1.2.10](https://github.com/fiction-com/factor/compare/v1.2.9...v1.2.10) (2020-02-04)


### Features

* **factor:** redo ([0e79511](https://github.com/fiction-com/factor/commit/0e7951187a49e9b588097bd7bd5d74ac0196fcda))



## [1.2.5](https://github.com/fiction-com/factor/compare/v1.2.4...v1.2.5) (2020-01-29)



## [1.2.2](https://github.com/fiction-com/factor/compare/v1.2.1...v1.2.2) (2020-01-27)



## [1.2.1](https://github.com/fiction-com/factor/compare/v1.2.0...v1.2.1) (2020-01-26)



# [1.2.0](https://github.com/fiction-com/factor/compare/v1.1.42...v1.2.0) (2020-01-26)



## [1.1.42](https://github.com/fiction-com/factor/compare/v1.1.41...v1.1.42) (2020-01-25)



## [1.1.40](https://github.com/fiction-com/factor/compare/v1.1.39...v1.1.40) (2020-01-22)



## [1.1.39](https://github.com/fiction-com/factor/compare/v1.1.38...v1.1.39) (2020-01-22)



## [1.1.37](https://github.com/fiction-com/factor/compare/v1.1.36...v1.1.37) (2020-01-22)



## [1.1.36](https://github.com/fiction-com/factor/compare/v1.1.35...v1.1.36) (2020-01-21)



## [1.1.35](https://github.com/fiction-com/factor/compare/v1.1.34...v1.1.35) (2020-01-21)



## [1.1.34](https://github.com/fiction-com/factor/compare/v1.1.33...v1.1.34) (2020-01-21)



## [1.1.33](https://github.com/fiction-com/factor/compare/v1.1.32...v1.1.33) (2020-01-18)



## [1.1.31](https://github.com/fiction-com/factor/compare/v1.1.30...v1.1.31) (2020-01-17)



## [1.1.30](https://github.com/fiction-com/factor/compare/v1.1.29...v1.1.30) (2020-01-17)



## [1.1.29](https://github.com/fiction-com/factor/compare/v1.1.28...v1.1.29) (2020-01-16)



## [1.1.28](https://github.com/fiction-com/factor/compare/v1.1.27...v1.1.28) (2020-01-16)



## [1.1.26](https://github.com/fiction-com/factor/compare/v1.1.25...v1.1.26) (2020-01-15)



## [1.1.24](https://github.com/fiction-com/factor/compare/v1.1.23...v1.1.24) (2020-01-15)



## [1.1.20](https://github.com/fiction-com/factor/compare/v1.1.19...v1.1.20) (2020-01-03)



## [1.1.18](https://github.com/fiction-com/factor/compare/v1.1.17...v1.1.18) (2020-01-01)



## [1.1.16](https://github.com/fiction-com/factor/compare/v1.1.16-alpha.0...v1.1.16) (2020-01-01)



## [1.1.5](https://github.com/fiction-com/factor/compare/v1.1.4...v1.1.5) (2019-12-09)



## [1.1.4](https://github.com/fiction-com/factor/compare/v1.1.3...v1.1.4) (2019-12-07)


### Bug Fixes

* **ts:** vue imports ([5c1046a](https://github.com/fiction-com/factor/commit/5c1046ae8b602f98c4ba107887660b2113c96818))


### Features

* **typescript:** [#452](https://github.com/fiction-com/factor/issues/452) to [#379](https://github.com/fiction-com/factor/issues/379) ([cd49700](https://github.com/fiction-com/factor/commit/cd497004c47ab7f9daa4fe82b137b1f292196ecf))
* **typescript:** [#6](https://github.com/fiction-com/factor/issues/6) ([aa4ec2e](https://github.com/fiction-com/factor/commit/aa4ec2e7c35ecde36307238413041c533f993d83))
* **typescript:** [#65](https://github.com/fiction-com/factor/issues/65) to [#0](https://github.com/fiction-com/factor/issues/0) ([ba63f53](https://github.com/fiction-com/factor/commit/ba63f536c9a3ace6c2efdbd0d177944eaf6549b4))
* **typescript:** migrate packages ([0413831](https://github.com/fiction-com/factor/commit/041383149fd506aae1c9dbafe05d4180543323db))



## [1.1.1](https://github.com/fiction-com/factor/compare/v1.1.0...v1.1.1) (2019-11-20)



# [1.1.0](https://github.com/fiction-com/factor/compare/v1.0.0-beta.18...v1.1.0) (2019-11-19)



# [1.0.0-beta.15](https://github.com/fiction-com/factor/compare/v1.0.0-beta.14...v1.0.0-beta.15) (2019-11-11)



# [1.0.0-beta.14](https://github.com/fiction-com/factor/compare/v1.0.0-beta.13...v1.0.0-beta.14) (2019-11-11)



# [1.0.0-beta.12](https://github.com/fiction-com/factor/compare/v1.0.0-beta.9...v1.0.0-beta.12) (2019-11-11)

==> plugin-highlight-code-1.8.28.tgz: package/CHANGELOG.md <==
## [1.5.7](https://github.com/fiction-com/factor/compare/v1.5.6...v1.5.7) (2020-03-24)

### Bug Fixes

- extend ([5e7abd6](https://github.com/fiction-com/factor/commit/5e7abd694919110e97382dcd4db1eab62f8d4f2a))

## [1.5.4](https://github.com/fiction-com/factor/compare/v1.5.3...v1.5.4) (2020-03-24)

### Bug Fixes

- **plugins:** svg icons ([2090322](https://github.com/fiction-com/factor/commit/2090322a2868420f85a8ff914a0ee7cfa2f99b4a))

## [1.4.2](https://github.com/fiction-com/factor/compare/v1.4.1...v1.4.2) (2020-02-27)

### Bug Fixes

- tweak fiction ([41ebfd6](https://github.com/fiction-com/factor/commit/41ebfd6689a3ac8dfd94a0ea6fd234c1345f043b))

## [1.3.11](https://github.com/fiction-com/factor/compare/v1.3.10...v1.3.11) (2020-02-21)

### Features

- forum ([1dbceed](https://github.com/fiction-com/factor/commit/1dbceed1db80f7f2ddeac2785c95c233c3e54fc3))

## [1.3.8](https://github.com/fiction-com/factor/compare/v1.3.7...v1.3.8) (2020-02-19)

### Features

- **forum:** closer ([506390e](https://github.com/fiction-com/factor/commit/506390e6606a564506180cb763a8052e684c3bc4))

## [1.3.5](https://github.com/fiction-com/factor/compare/v1.3.4...v1.3.5) (2020-02-17)

### Bug Fixes

- old code ([50a50be](https://github.com/fiction-com/factor/commit/50a50bec02a7f231bfd58ee1169f992cf76d6061))
- old css ([ffa1bb5](https://github.com/fiction-com/factor/commit/ffa1bb54079c1f6a3ce5492496b22a81ddccb91a))

### Features

- **code:** highlight ([d52a121](https://github.com/fiction-com/factor/commit/d52a121efd48074bc8b24f00bdf364cea55effff))
- **forum:** refactor ([4aa89bb](https://github.com/fiction-com/factor/commit/4aa89bb75afb09e202717f1509c74266fc08d9aa))

## [1.3.1](https://github.com/fiction-com/factor/compare/v1.3.0...v1.3.1) (2020-02-04)

# [1.3.0](https://github.com/fiction-com/factor/compare/v1.2.10...v1.3.0) (2020-02-04)

## [1.2.10](https://github.com/fiction-com/factor/compare/v1.2.9...v1.2.10) (2020-02-04)

### Features

- **factor:** redo ([0e79511](https://github.com/fiction-com/factor/commit/0e7951187a49e9b588097bd7bd5d74ac0196fcda))

## [1.2.5](https://github.com/fiction-com/factor/compare/v1.2.4...v1.2.5) (2020-01-29)

## [1.2.2](https://github.com/fiction-com/factor/compare/v1.2.1...v1.2.2) (2020-01-27)

## [1.2.1](https://github.com/fiction-com/factor/compare/v1.2.0...v1.2.1) (2020-01-26)

# [1.2.0](https://github.com/fiction-com/factor/compare/v1.1.42...v1.2.0) (2020-01-26)

## [1.1.42](https://github.com/fiction-com/factor/compare/v1.1.41...v1.1.42) (2020-01-25)

## [1.1.40](https://github.com/fiction-com/factor/compare/v1.1.39...v1.1.40) (2020-01-22)

## [1.1.39](https://github.com/fiction-com/factor/compare/v1.1.38...v1.1.39) (2020-01-22)

## [1.1.37](https://github.com/fiction-com/factor/compare/v1.1.36...v1.1.37) (2020-01-22)

## [1.1.36](https://github.com/fiction-com/factor/compare/v1.1.35...v1.1.36) (2020-01-21)

## [1.1.35](https://github.com/fiction-com/factor/compare/v1.1.34...v1.1.35) (2020-01-21)

## [1.1.34](https://github.com/fiction-com/factor/compare/v1.1.33...v1.1.34) (2020-01-21)

## [1.1.33](https://github.com/fiction-com/factor/compare/v1.1.32...v1.1.33) (2020-01-18)

## [1.1.31](https://github.com/fiction-com/factor/compare/v1.1.30...v1.1.31) (2020-01-17)

## [1.1.30](https://github.com/fiction-com/factor/compare/v1.1.29...v1.1.30) (2020-01-17)

## [1.1.29](https://github.com/fiction-com/factor/compare/v1.1.28...v1.1.29) (2020-01-16)

## [1.1.28](https://github.com/fiction-com/factor/compare/v1.1.27...v1.1.28) (2020-01-16)

## [1.1.26](https://github.com/fiction-com/factor/compare/v1.1.25...v1.1.26) (2020-01-15)

## [1.1.24](https://github.com/fiction-com/factor/compare/v1.1.23...v1.1.24) (2020-01-15)

## [1.1.20](https://github.com/fiction-com/factor/compare/v1.1.19...v1.1.20) (2020-01-03)

## [1.1.18](https://github.com/fiction-com/factor/compare/v1.1.17...v1.1.18) (2020-01-01)

## [1.1.16](https://github.com/fiction-com/factor/compare/v1.1.16-alpha.0...v1.1.16) (2020-01-01)

## [1.1.5](https://github.com/fiction-com/factor/compare/v1.1.4...v1.1.5) (2019-12-09)

## [1.1.4](https://github.com/fiction-com/factor/compare/v1.1.3...v1.1.4) (2019-12-07)

### Bug Fixes

- **ts:** vue imports ([5c1046a](https://github.com/fiction-com/factor/commit/5c1046ae8b602f98c4ba107887660b2113c96818))

### Features

- **typescript:** [#452](https://github.com/fiction-com/factor/issues/452) to [#379](https://github.com/fiction-com/factor/issues/379) ([cd49700](https://github.com/fiction-com/factor/commit/cd497004c47ab7f9daa4fe82b137b1f292196ecf))
- **typescript:** [#6](https://github.com/fiction-com/factor/issues/6) ([aa4ec2e](https://github.com/fiction-com/factor/commit/aa4ec2e7c35ecde36307238413041c533f993d83))
- **typescript:** [#65](https://github.com/fiction-com/factor/issues/65) to [#0](https://github.com/fiction-com/factor/issues/0) ([ba63f53](https://github.com/fiction-com/factor/commit/ba63f536c9a3ace6c2efdbd0d177944eaf6549b4))
- **typescript:** migrate packages ([0413831](https://github.com/fiction-com/factor/commit/041383149fd506aae1c9dbafe05d4180543323db))

## [1.1.1](https://github.com/fiction-com/factor/compare/v1.1.0...v1.1.1) (2019-11-20)

# [1.1.0](https://github.com/fiction-com/factor/compare/v1.0.0-beta.18...v1.1.0) (2019-11-19)

# [1.0.0-beta.15](https://github.com/fiction-com/factor/compare/v1.0.0-beta.14...v1.0.0-beta.15) (2019-11-11)

# [1.0.0-beta.14](https://github.com/fiction-com/factor/compare/v1.0.0-beta.13...v1.0.0-beta.14) (2019-11-11)

# [1.0.0-beta.12](https://github.com/fiction-com/factor/compare/v1.0.0-beta.9...v1.0.0-beta.12) (2019-11-11)
